--[[
		    ----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----

                            #########  #  #######       ####     #       #    ####       ######       ######    #
                            #          #  #     ##    ##    ##   ##      #   ##  ##    ##      ##   ##      ##  #
                            #          #  #       #  ##      ##  # #     #  #      #  ##           ##           #
                            #          #  #     ##   #        #  #  #    #  #      #  #            #            #
                            #######    #  #######    #        #  #   #   #  ########  #            #            #
                            #          #  #     ##   #        #  #    #  #  #      #  #            #            #
                            #          #  #       #  ##      ##  #     # #  #      #  ##           ##           #
                            #          #  #     ##    ##    ##   #      ##  #      #   ##      ##   ##      ##  #
                            #          #  #######       ####     #       #  #      #     ######       ######    #

		    ----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----(||)----o----


						    ----o----(||)----oo----(||)----o----

							  v1.04 3rd September 2017
						    Copyright (C) Taraezor / Chris Birch

						    ----o----(||)----oo----(||)----o----

]]
--------------------------------------------------------------------------------------------------------------------------------------------

local addonName, L = ...
local macroName = L["Fibonacci"]

local modf = math.modf
local find = string.find
local format = string.format
local gmatch = string.gmatch
local gsub = string.gsub
local lower = string.lower
local rep = string.rep
local sub = string.sub
local insert = table.insert
local remove = table.remove
local tonumber = tonumber
local tostring = tostring

local debugprofilestop = debugprofilestop
local GetTime = GetTime
local InCombatLockdown = InCombatLockdown
local PlaySound = PlaySound
local StopSound = StopSound
local UnitFactionGroup = UnitFactionGroup

--------------------------------------------------------------------------------------------------------------------------------------------
-- Print Colours
--------------------------------------------------------------------------------------------------------------------------------------------

local pc_colour_Prefix		= "\124cFF1E90FF"
local pc_colour_Highlight	= "\124cFF4169E1"
local pc_colour_PlainText	= "\124cFF87CEFA"

local function printPC( message )
	DEFAULT_CHAT_FRAME:AddMessage( pc_colour_Prefix.. addonName.. ": ".. pc_colour_PlainText.. message.. "\124r" )
end

--------------------------------------------------------------------------------------------------------------------------------------------
-- Print Latest Result
--------------------------------------------------------------------------------------------------------------------------------------------

local function PrintLatest()

	if not FibonacciResultsDB then return end
	printPC( "#".. FibonacciDB.fibNum.. " = ".. pc_colour_Highlight.. FibonacciResultsDB[ #FibonacciResultsDB ]:sub( 1, 100 ) )
end

--------------------------------------------------------------------------------------------------------------------------------------------
-- OnEvent
--------------------------------------------------------------------------------------------------------------------------------------------

local restart = true

function Fibonacci_OnUpdate( self, elapsed )

	self.timeSinceLastUpdate = self.timeSinceLastUpdate + elapsed

	if ( FibonacciDB.on and FibonacciDB.on == "n" ) or FibonacciDB.finished or InCombatLockdown() then return end

	local timeIn = debugprofilestop()
	local timeIsUp = nil

	if restart or not FibonacciDB.step then
		if not FibonacciDB.step or not FibonacciDB.on then FibonacciDB.on = "n" end

		if not FibonacciDB.pause	then FibonacciDB.pause		= 1000	end
		if not FibonacciDB.duration	then FibonacciDB.duration	= 10	end
		if not FibonacciDB.sound	then FibonacciDB.sound		= ""	end
		if not FibonacciDB.retain	then FibonacciDB.retain		= 10	end
		if not FibonacciDB.method	then FibonacciDB.method		= 1	end

		if not FibonacciDB.a or not FibonacciDB.b or not FibonacciDB.fibNum or not FibonacciResultsDB then
			FibonacciDB.a = "1"
			FibonacciDB.b = "1"
			FibonacciDB.fibNum = "2"
			FibonacciResultsDB = { "1", "1" }
		end

		FibonacciDB.step, restart, FibonacciDB.start = 0, nil, timeIn
	end

	if self.timeSinceLastUpdate < ( FibonacciDB.pause / 1000 ) then return end
	self.timeSinceLastUpdate = 0

	if FibonacciDB.method == 1 then

		local chunk = 14
		local chunkMinusOne, tensPowered = chunk - 1, 10 ^ chunk
		local divisions = floor( #FibonacciDB.b / chunk )
		local head = #FibonacciDB.b - ( divisions * chunk )
		local diffAB = #FibonacciDB.b - #FibonacciDB.a

		if FibonacciDB.step == 0 then					-- Setup the next step
			FibonacciDB.c, FibonacciDB.indexA, FibonacciDB.carryA = "", divisions, 0
			FibonacciDB.step = 1
		end

		if FibonacciDB.step == 1 then					-- Sum "a" and "b" -> "c"
			if FibonacciDB.indexA < 0 then
				FibonacciDB.c, FibonacciDB.indexA, FibonacciDB.carryA = "", divisions, 0
			end
			for i = FibonacciDB.indexA, 1, -1 do
				local segB = tonumber( FibonacciDB.b:sub( i * chunk - chunkMinusOne + head, i * chunk + head ) )
				local startA = i * chunk - chunkMinusOne + head - diffAB
				local segA = tonumber( FibonacciDB.a:sub( (( startA == 0 ) and 1 or startA), ( i * chunk + head - diffAB )) )
				segB = segB + segA + FibonacciDB.carryA
				FibonacciDB.indexA = -1
				if segB >= tensPowered then
					FibonacciDB.carryA = 1
					segB = segB - tensPowered
				else
					FibonacciDB.carryA = 0
				end
				FibonacciDB.c = sub( "000000000000000".. format( "%.0f", segB ), -chunk ).. FibonacciDB.c
				FibonacciDB.indexA = i - 1
				if debugprofilestop() > ( timeIn + FibonacciDB.duration ) then
					timeIsUp = true
					break
				 end
			end
			if timeIsUp then return end
			FibonacciDB.step = 2
		end

		if FibonacciDB.step == 2 then					-- add in the leading partial division
			if head > 0 then
				local finA = head - diffAB
				local segA = ( finA > 0 ) and tonumber( FibonacciDB.a:sub( 1, finA ) ) or 0
				local segB = tonumber( FibonacciDB.b:sub( 1, head ) ) + segA + FibonacciDB.carryA
				FibonacciDB.c = segB.. FibonacciDB.c
			elseif FibonacciDB.carryA > 0 then
				FibonacciDB.c = "1".. FibonacciDB.c
			end
			FibonacciDB.step = 3
		end

		if FibonacciDB.step == 3 then					-- Shuffle down. "a" is now the old "b"
			FibonacciDB.a = FibonacciDB.b
			FibonacciDB.step = 4
		end

		if FibonacciDB.step == 4 then					-- The new "b" is "c"
			FibonacciDB.b = FibonacciDB.c
			FibonacciDB.c = ""
			FibonacciDB.step = 6
		end

	elseif FibonacciDB.method == 2 then

		if FibonacciDB.step == 0 then					-- Setup the next step
			FibonacciDB.c, FibonacciDB.indexA, FibonacciDB.carryA = "", #FibonacciDB.a, 0
			FibonacciDB.indexOffsetB = #FibonacciDB.b - #FibonacciDB.a
			FibonacciDB.step = 1
		end

		if FibonacciDB.step == 1 then					-- Sum "a" and "b" -> "c"
			if FibonacciDB.indexA < 0 then
				FibonacciDB.c, FibonacciDB.indexA, FibonacciDB.carryA = "", #FibonacciDB.a, 0
			end
			for i = FibonacciDB.indexA, 1, -1 do
				local aNum = tonumber( FibonacciDB.a:sub( i, i ) )
				local bNum = tonumber( FibonacciDB.b:sub( i+FibonacciDB.indexOffsetB, i+FibonacciDB.indexOffsetB ) ) + FibonacciDB.carryA
				FibonacciDB.indexA = -1
				local rem, cNum = modf( ( aNum + bNum ) / 10 )
				FibonacciDB.carryA = rem
				FibonacciDB.c =  tostring( cNum * 10 ).. FibonacciDB.c
				FibonacciDB.indexA = i-1
				if debugprofilestop() > ( timeIn + FibonacciDB.duration ) then
					timeIsUp = true
					break
				 end
			end
			if timeIsUp then return end
			FibonacciDB.step = 2
		end

		if FibonacciDB.step == 2 then					-- "b" might be larger than "a" so add the extra to "d"
			local bNum = FibonacciDB.carryA
			if FibonacciDB.indexOffsetB > 0 then
				bNum = bNum + tonumber( FibonacciDB.b:sub( 1, 1 ) )
			end
			if bNum > 0 then
				FibonacciDB.d =  tostring( bNum )
			else
				FibonacciDB.d = ""
			end
			FibonacciDB.step = 3
		end

		if FibonacciDB.step == 3 then					-- Shuffle down. "a" is now the old "b"
			FibonacciDB.a = FibonacciDB.b
			FibonacciDB.step = 4
		end

		if FibonacciDB.step == 4 then					-- The new "b" is "c" + "d"
			FibonacciDB.b = FibonacciDB.d.. FibonacciDB.c
			FibonacciDB.step = 5
		end

		if FibonacciDB.step == 5 then					-- free up resources
			FibonacciDB.c, FibonacciDB.d = "", ""
			FibonacciDB.step = 6
		end
	end


	if FibonacciDB.step == 6 then					-- Results are saved into a table. Added at the end of the table
		insert( FibonacciResultsDB, FibonacciDB.b )
		FibonacciDB.step = 7
	end

	if FibonacciDB.step == 7 then					-- Retain only the required number of results
		repeat
			if #FibonacciResultsDB <= FibonacciDB.retain then break end
			remove( FibonacciResultsDB, 1 )
		until false
		FibonacciDB.newFN, FibonacciDB.indexFN, FibonacciDB.carryFN = "", #FibonacciDB.fibNum, 1	-- Setup the next step
		FibonacciDB.step = 8
	end

	if FibonacciDB.step == 8 then					-- fibNum is the sequence index STRING, e.g. F(1) = 1, F(2) = 1, F(3) = 2, F(4) = 3, etc
									-- Need to add 1
		if FibonacciDB.indexFN < 0 then
			FibonacciDB.c, FibonacciDB.indexFN, FibonacciDB.carryFN = "", #FibonacciDB.fibNum, 1
		end
		for i = FibonacciDB.indexFN, 1, -1 do
			local fNum = tonumber( FibonacciDB.fibNum:sub( i, i ) ) + FibonacciDB.carryFN
			FibonacciDB.indexFN = -1
			local rem, gNum = modf( fNum / 10 )
			FibonacciDB.carryFN = rem
			FibonacciDB.newFN =  tostring( gNum * 10 ).. FibonacciDB.newFN
			FibonacciDB.indexFN = i-1
			if debugprofilestop() > ( timeIn + FibonacciDB.duration ) then
				timeIsUp = true
				break
			 end
		end
		if timeIsUp then return end
		if FibonacciDB.carryFN > 0 then
			FibonacciDB.newFN = tostring( FibonacciDB.carryFN ).. FibonacciDB.newFN
		end
		FibonacciDB.step = 9
	end

	if FibonacciDB.step == 9 then
		FibonacciDB.fibNum = FibonacciDB.newFN
		FibonacciDB.step = 10
	end

	if FibonacciDB.step == 10 then
		FibonacciDB.newFN = nil
		FibonacciDB.step = 11

if find( FibonacciResultsDB[ #FibonacciResultsDB ], "000000000", 1, true ) then
	printPC( "Zeroes! @ ".. FibonacciDB.fibNum )
	PlaySoundFile( "Sound\\Events\\gruntling_horn_bb.ogg" )
	FibonacciDB.on = "n"
end

	end

	if FibonacciDB.step == 11 then					-- Finish and alert player if the fibNum has reached the requested index
		if FibonacciDB.finishIndex then
			local finishIndex, fibNum, zeroes = FibonacciDB.finishIndex, FibonacciDB.fibNum, ""
			if #fibNum > #finishIndex then
				zeroes = string.rep( "0", ( #fibNum - #finishIndex ) )
				finishIndex = zeroes.. finishIndex
			elseif #fibNum < #finishIndex then
				zeroes = string.rep( "0", ( #finishIndex - #fibNum ) )
				fibNum = zeroes.. fibNum
			end
			if fibNum >= finishIndex then
				FibonacciDB.on = "n"
				FibonacciDB.finished = "y"
				PrintLatest()
				PlaySoundFile( FibonacciDB.sound )

--				printPC( "Elapsed = ".. ( debugprofilestop() - FibonacciDB.start ) )

			end
		end
		FibonacciDB.step = 0
	end
end


--------------------------------------------------------------------------------------------------------------------------------------------
-- Slash Commands
--------------------------------------------------------------------------------------------------------------------------------------------

local soundkitHandle = nil

SLASH_Fibonacci1, SLASH_Fibonacci2 = "/fibonacci", "/fib"

SlashCmdList[ "Fibonacci" ] = function( options )

	local stopAtFibonacciIndexN = L["Stop at Fibonacci index ~n~"]
	local keepTheMostRecentN = L["Keep the most recent ~n~"]
	local mustBeNumericAnd = L["\"n\" must be numeric and ~i~"]
	local secondParm, options1

	if not FibonacciDB.pause	then FibonacciDB.pause		= 1000	end
	if not FibonacciDB.duration	then FibonacciDB.duration	= 10	end
	if not FibonacciDB.sound	then FibonacciDB.sound		= ""	end
	if not FibonacciDB.retain	then FibonacciDB.retain		= 10	end
	if not FibonacciDB.method	then FibonacciDB.method		= 1	end
	if not FibonacciDB.fibNum then
		FibonacciDB.a = "1"
		FibonacciDB.b = "1"
		FibonacciDB.fibNum = "2"
		FibonacciResultsDB = { "1", "1" }
	end

	for v in gmatch( options, "(%S+)" ) do
		v = lower(v)
		if not options1 then
			options1 = sub( v,1,1 )
		else
			secondParm = sub( v,1 )
			break
		end
	end

	if ( options1 == "?" ) or ( options1 == nil ) then
		stopAtFibonacciIndexN = gsub( stopAtFibonacciIndexN, "~n~", "\"n\"" )
		keepTheMostRecentN = gsub( keepTheMostRecentN, "~n~", "\"n\"" )
		printPC( pc_colour_Highlight.. L["Macro Commands"].. ":\n"..
			pc_colour_Highlight.. "o".. pc_colour_PlainText.. " = ".. L["Turn on / off"].. ". (".. L["Toggle"].. ")\n"..
			pc_colour_Highlight.. "p n".. pc_colour_PlainText.. " = ".. L["Pause"].. ". (n = ".. L["milliseconds"].. ". >= 10)\n"..
			pc_colour_Highlight.. "d n".. pc_colour_PlainText.. " = ".. L["Duration"].. ". (n = ".. L["milliseconds"].. ". >= 1)\n"..
			pc_colour_Highlight.. "s".. pc_colour_PlainText.. " = ".. L["Sound"].. ". (".. L["Toggle"].. ")\n"..
			pc_colour_Highlight.. "i n".. pc_colour_PlainText.. " = ".. stopAtFibonacciIndexN.. ". (n >= 2)\n"..
			pc_colour_Highlight.. "k n".. pc_colour_PlainText.. " = ".. keepTheMostRecentN.. ". (n >= 1)\n"..
			pc_colour_Highlight.. "m n".. pc_colour_PlainText.. " = ".. L["Method"].. ". (1 <= n <= 2)\n"..
			pc_colour_Highlight.. "r".. pc_colour_PlainText.. " = ".. L["Report"].. "\n"..
			pc_colour_Highlight.. "x".. pc_colour_PlainText.. " = ".. L["Reset"].. "\n"..
			pc_colour_Highlight.. "v".. pc_colour_PlainText.. " = ".. L["Show the version number"].. "\n")

	elseif ( options1 == "o" ) then
		if secondParm and ( secondParm == "?" ) then
		else
			FibonacciDB.on = ( FibonacciDB.on == "y" ) and "n" or "y"
		end
		if ( FibonacciDB.on == "y" ) then
			printPC( L["On"] )
		else
			printPC( L["Off"] )
		end

	elseif ( options1 == "p" ) then
		local parm = tonumber( secondParm )
		if parm and ( parm >= 10 ) then
			FibonacciDB.pause = parm
			printPC( L["Pause"].. " = ".. pc_colour_Highlight.. FibonacciDB.pause )
		elseif secondParm and ( secondParm == "?" ) then
			printPC( L["Pause"].. " = ".. pc_colour_Highlight.. FibonacciDB.pause )
		else
			mustBeNumericAnd = gsub( mustBeNumericAnd, "~i~", ">= 10" )
			printPC( mustBeNumericAnd )
		end

	elseif ( options1 == "d" ) then
		local parm = tonumber( secondParm )
		if parm and ( parm >= 1 ) then
			FibonacciDB.duration = parm
			printPC( L["Duration"].. " = ".. pc_colour_Highlight.. FibonacciDB.duration )
		elseif secondParm and ( secondParm == "?" ) then
			printPC( L["Duration"].. " = ".. pc_colour_Highlight.. FibonacciDB.duration )
		else
			mustBeNumericAnd = gsub( mustBeNumericAnd, "~i~", ">= 1" )
			printPC( mustBeNumericAnd )
		end

	elseif ( options1 == "s" ) then
		if secondParm and ( secondParm == "?" ) then
			-- just play the current sound
		elseif FibonacciDB.sound == "" then
			FibonacciDB.sound = "Sound\\Events\\scourge_horn.ogg"
		elseif FibonacciDB.sound == "Sound\\Events\\scourge_horn.ogg" then
			FibonacciDB.sound = "Sound\\Event Sounds\\Event_wardrum_ogre.ogg"
		elseif FibonacciDB.sound == "Sound\\Event Sounds\\Event_wardrum_ogre.ogg" then
			FibonacciDB.sound = "Sound\\Events\\gruntling_horn_bb.ogg"
		elseif FibonacciDB.sound == "Sound\\Events\\gruntling_horn_bb.ogg" then
			FibonacciDB.sound = "Sound\\Spells\\Shaysbell.ogg"
		elseif FibonacciDB.sound == "Sound\\Spells\\Shaysbell.ogg" then
			FibonacciDB.sound = "Sound\\Spells\\Fairytale_Sfx_01.ogg"
		elseif FibonacciDB.sound == "Sound\\Spells\\Fairytale_Sfx_01.ogg" then
			FibonacciDB.sound = ""
		end
		if FibonacciDB.sound == "" then
			printPC( L["Sound"].. " = ".. pc_colour_Highlight.. L["Silent"] )
		else
			printPC( L["Sound"].. " = ".. pc_colour_Highlight.. FibonacciDB.sound )
		end
		PlaySoundFile( FibonacciDB.sound )

	elseif ( options1 == "i" ) then
		if secondParm then
			if find( secondParm, "%D" ) then
				if secondParm and ( secondParm == "?" ) then
					if FibonacciDB.finishIndex then
						stopAtFibonacciIndexN = gsub( stopAtFibonacciIndexN, "~n~", pc_colour_Highlight.. FibonacciDB.finishIndex.. pc_colour_Prefix )
					else
						stopAtFibonacciIndexN = gsub( stopAtFibonacciIndexN, "~n~", pc_colour_Highlight.. L["infinity"].. pc_colour_Prefix )
					end
					printPC( stopAtFibonacciIndexN )
				else
					mustBeNumericAnd = gsub( mustBeNumericAnd, "~i~", ">= 2" )
					printPC( mustBeNumericAnd )
				end
			else
				if #secondParm == 1 then
					if tonumber( secondParm ) < 2 then
						mustBeNumericAnd = gsub( mustBeNumericAnd, "~i~", ">= 2" )
						printPC( mustBeNumericAnd )
						return
					end
				end
				FibonacciDB.finishIndex, FibonacciDB.finished = secondParm, nil
				stopAtFibonacciIndexN = gsub( stopAtFibonacciIndexN, "~n~", pc_colour_Highlight.. FibonacciDB.finishIndex.. pc_colour_Prefix )
				printPC( stopAtFibonacciIndexN )

				local fibNum, zeroes = FibonacciDB.fibNum, ""
				if #fibNum > #secondParm then
					zeroes = string.rep( "0", ( #fibNum - #secondParm ) )
					secondParm = zeroes.. secondParm
				elseif #fibNum < #secondParm then
					zeroes = string.rep( "0", ( #secondParm - #fibNum ) )
					fibNum = zeroes.. fibNum
				end
				if fibNum > secondParm then
					restart = "y"
				elseif fibNum == secondParm then
					FibonacciDB.finished = "y"
				end
			end
		else
			FibonacciDB.finishIndex, FibonacciDB.finished = nil, nil
			stopAtFibonacciIndexN = gsub( stopAtFibonacciIndexN, "~n~", pc_colour_Highlight.. L["infinity"].. pc_colour_Prefix )
			printPC( stopAtFibonacciIndexN )
		end

	elseif ( options1 == "k" ) then
		local parm = tonumber( secondParm )
		if parm and ( parm >= 1 ) then
			FibonacciDB.retain = parm
		elseif secondParm and ( secondParm == "?" ) then
		else
			mustBeNumericAnd = gsub( mustBeNumericAnd, "~i~", ">= 1" )
			printPC( mustBeNumericAnd )
			return
		end
		keepTheMostRecentN = gsub( keepTheMostRecentN, "~n~", pc_colour_Highlight.. FibonacciDB.retain.. pc_colour_Prefix )
		printPC( keepTheMostRecentN )

	elseif ( options1 == "m" ) then
		local parm = tonumber( secondParm )
		if parm and ( parm == 1 or parm == 2 ) then
			FibonacciDB.method = parm
			printPC( L["Method"].. " = ".. pc_colour_Highlight.. FibonacciDB.method )
		elseif secondParm and ( secondParm == "?" ) then
			printPC( L["Method"].. " = ".. pc_colour_Highlight.. FibonacciDB.method )
		elseif FibonacciDB.on == "y" then
			local mustBeSwitchedOff = L["~n~ must be switched off"]
			mustBeSwitchedOff = gsub( mustBeSwitchedOff, "~n~", addonName )
			printPC( mustBeSwitchedOff )
		else
			mustBeNumericAnd = gsub( mustBeNumericAnd, "~i~", "= 1 / 2" )
			printPC( mustBeNumericAnd )
		end

	elseif ( options1 == "r" ) then
		if ( FibonacciDB.on == "y" ) then
			printPC( L["On"].. pc_colour_Highlight.. " (".. FibonacciDB.fibNum.. "...)" )
		else
			printPC( L["Off"].. pc_colour_Highlight.. " (".. FibonacciDB.fibNum.. ")" )
		end
		printPC( L["Pause"].. " = ".. pc_colour_Highlight.. FibonacciDB.pause )
		printPC( L["Duration"].. " = ".. pc_colour_Highlight.. FibonacciDB.duration )
		if FibonacciDB.sound == "" then
			printPC( L["Sound"].. " = ".. pc_colour_Highlight.. L["Silent"] )
		else
			printPC( L["Sound"].. " = ".. pc_colour_Highlight.. FibonacciDB.sound )
		end
		if FibonacciDB.finishIndex then
			stopAtFibonacciIndexN = gsub( stopAtFibonacciIndexN, "~n~", pc_colour_Highlight.. FibonacciDB.finishIndex.. pc_colour_Prefix )
		else
			stopAtFibonacciIndexN = gsub( stopAtFibonacciIndexN, "~n~", pc_colour_Highlight.. L["infinity"].. pc_colour_Prefix )
		end
		printPC( stopAtFibonacciIndexN )
		keepTheMostRecentN = gsub( keepTheMostRecentN, "~n~", pc_colour_Highlight.. FibonacciDB.retain.. pc_colour_Prefix )
		printPC( keepTheMostRecentN )
		printPC( L["Method"].. " = ".. pc_colour_Highlight.. FibonacciDB.method )
		PrintLatest()

	elseif ( options1 == "x" ) then
		FibonacciDB = {}
		printPC( L["Reset"] )

	elseif ( options1 == "v" ) then
		local version = GetAddOnMetadata( addonName, "Version" )
		printPC( L["Version: "].. pc_colour_Highlight.. version )

	-- Easter Eggs. Enjoy!

	elseif ( options1 == "z" ) then
		if ( soundkitHandle ) then
			StopSound( soundkitHandle, 5000 )
			soundkitHandle = nil
		else
			local soundSelection = random( 3 )
			if ( soundSelection == 1 ) then
				_, soundkitHandle = PlaySound( 11805 )	-- Pirate Tavern
			elseif ( soundSelection == 2 ) then
				_, soundkitHandle = PlaySound( 8440 )	-- Darkmoon Faire
			else
				local faction = UnitFactionGroup( "player" )
				if ( faction == "Alliance" ) then
					_, soundkitHandle = PlaySound( 12319 )	-- Midsummer Festival Alliance
				else
					_, soundkitHandle = PlaySound( 12325 )	-- Midsummer Festival Horde
				end
			end
		end
	end
end